@@ -14,80 +14,326 @@ All consolidated into a focused solving system.
 
 from __future__ import annotations
 
+import ast
+import operator
 import re
 from logging import Logger
 from typing import Any
 
-from ..equations import Equation
-from ..expressions import BinaryOperation, ConditionalExpression, Constant, UnaryFunction, VariableReference, cos, sin
-from ..quantities import FieldQnty
+from ..algebra import BinaryOperation, ConditionalExpression, Constant, Equation, UnaryFunction, VariableReference, cos, sin
+from ..algebra import equation as create_equation
+from ..core.quantity import Quantity
+from ..utils.shared_utilities import (
+    PatternMatchingHelper,
+    SafeExecutionMixin,
+)
 
 # Type aliases for better readability
-VariableDict = dict[str, FieldQnty]
+VariableDict = dict[str, Quantity]
 ReconstructionResult = Equation | None
 NamespaceMapping = dict[str, str]
 
-# Constants for pattern matching
-CONDITIONAL_PATTERNS: set[str] = {"cond("}
-FUNCTION_PATTERNS: set[str] = {"sin(", "cos(", "tan(", "log(", "exp(", "sqrt"}
-MATH_OPERATORS: set[str] = {"(", ")", "+", "-", "*", "/"}
-EXCLUDED_FUNCTION_NAMES: set[str] = {"sin", "cos", "max", "min", "exp", "log", "sqrt", "tan"}
 
-# Compiled regex patterns for performance
-VARIABLE_PATTERN_DETAILED = re.compile(r"\b([a-zA-Z_][a-zA-Z0-9_]*)\b")
-VARIABLE_PATTERN = re.compile(r"\b[A-Za-z][A-Za-z0-9_]*\b")
+class SafeExpressionEvaluator:
+    """Safe mathematical expression evaluator using AST instead of eval()."""
+
+    ALLOWED_NODES = (
+        ast.Expression,
+        ast.BinOp,
+        ast.UnaryOp,
+        ast.Constant,
+        ast.Name,
+        ast.Load,
+        ast.Store,
+        ast.Del,
+        ast.Add,
+        ast.Sub,
+        ast.Mult,
+        ast.Div,
+        ast.Mod,
+        ast.Pow,
+        ast.LShift,
+        ast.RShift,
+        ast.BitOr,
+        ast.BitXor,
+        ast.BitAnd,
+        ast.FloorDiv,
+        ast.UAdd,
+        ast.USub,
+        ast.Not,
+        ast.Invert,
+        ast.Compare,
+        ast.Eq,
+        ast.NotEq,
+        ast.Lt,
+        ast.LtE,
+        ast.Gt,
+        ast.GtE,
+        ast.Is,
+        ast.IsNot,
+        ast.In,
+        ast.NotIn,
+        ast.BoolOp,
+        ast.And,
+        ast.Or,
+        ast.Call,
+        ast.keyword,
+        ast.Attribute,
+    )
+
+    OPERATORS = {
+        ast.Add: operator.add,
+        ast.Sub: operator.sub,
+        ast.Mult: operator.mul,
+        ast.Div: operator.truediv,
+        ast.FloorDiv: operator.floordiv,
+        ast.Mod: operator.mod,
+        ast.Pow: operator.pow,
+        ast.LShift: operator.lshift,
+        ast.RShift: operator.rshift,
+        ast.BitOr: operator.or_,
+        ast.BitXor: operator.xor,
+        ast.BitAnd: operator.and_,
+        ast.UAdd: operator.pos,
+        ast.USub: operator.neg,
+        ast.Not: operator.not_,
+        ast.Invert: operator.invert,
+        ast.Eq: operator.eq,
+        ast.NotEq: operator.ne,
+        ast.Lt: operator.lt,
+        ast.LtE: operator.le,
+        ast.Gt: operator.gt,
+        ast.GtE: operator.ge,
+        ast.Is: operator.is_,
+        ast.IsNot: operator.is_not,
+        ast.In: lambda a, b: a in b,
+        ast.NotIn: lambda a, b: a not in b,
+    }
+
+    # Standard allowed functions for safe evaluation
+    DEFAULT_ALLOWED_FUNCTIONS = {
+        "sin": sin,
+        "cos": cos,
+        "abs": abs,
+        "min": min,
+        "max": max,
+    }
+
+    def __init__(self, variables: dict[str, Any], allowed_functions: dict[str, Any] | None = None):
+        self.variables = variables
+        self.allowed_functions = allowed_functions or self.DEFAULT_ALLOWED_FUNCTIONS.copy()
+
+    def safe_eval(self, expr_string: str) -> Any:
+        """Safely evaluate a mathematical expression string."""
+        try:
+            tree = ast.parse(expr_string, mode="eval")
+            self._validate_ast(tree)
+            return self._eval_node(tree.body)
+        except (SyntaxError, ValueError, TypeError) as e:
+            raise ValueError(f"Invalid expression: {e}") from e
+
+    def _validate_ast(self, node: ast.AST) -> None:
+        """Validate that AST only contains allowed nodes."""
+        for child in ast.walk(node):
+            if not isinstance(child, self.ALLOWED_NODES):
+                raise ValueError(f"Disallowed node type: {type(child).__name__}")
+
+    def _eval_node(self, node: ast.AST) -> Any:
+        """Recursively evaluate AST nodes."""
+        if isinstance(node, ast.Constant):
+            return node.value
+        elif isinstance(node, ast.Name):
+            if node.id in self.variables:
+                return self.variables[node.id]
+            elif node.id in self.allowed_functions:
+                return self.allowed_functions[node.id]
+            else:
+                raise NameError(f"Unknown variable or function: {node.id}")
+        elif isinstance(node, ast.BinOp):
+            left = self._eval_node(node.left)
+            right = self._eval_node(node.right)
+            op = self.OPERATORS.get(type(node.op))
+            if op is None:
+                raise ValueError(f"Unsupported binary operator: {type(node.op).__name__}")
+            return op(left, right)
+        elif isinstance(node, ast.UnaryOp):
+            operand = self._eval_node(node.operand)
+            op = self.OPERATORS.get(type(node.op))
+            if op is None:
+                raise ValueError(f"Unsupported unary operator: {type(node.op).__name__}")
+            return op(operand)
+        elif isinstance(node, ast.Compare):
+            left = self._eval_node(node.left)
+            for op, comparator in zip(node.ops, node.comparators, strict=False):
+                right = self._eval_node(comparator)
+                comp_op = self.OPERATORS.get(type(op))
+                if comp_op is None:
+                    raise ValueError(f"Unsupported comparison operator: {type(op).__name__}")
+                if not comp_op(left, right):
+                    return False
+                left = right  # For chained comparisons
+            return True
+        elif isinstance(node, ast.BoolOp):
+            if isinstance(node.op, ast.And):
+                return all(self._eval_node(value) for value in node.values)
+            elif isinstance(node.op, ast.Or):
+                return any(self._eval_node(value) for value in node.values)
+        elif isinstance(node, ast.Call):
+            func_name = node.func.id if isinstance(node.func, ast.Name) else None
+            if func_name is None or func_name not in self.allowed_functions:
+                raise ValueError(f"Function not allowed: {func_name}")
+            func = self.allowed_functions[func_name]
+            args = [self._eval_node(arg) for arg in node.args]
+            kwargs = {kw.arg: self._eval_node(kw.value) for kw in node.keywords if kw.arg is not None}
+            return func(*args, **kwargs)
+        elif isinstance(node, ast.Attribute):
+            obj = self._eval_node(node.value)
+            return getattr(obj, node.attr)
+        else:
+            raise ValueError(f"Unsupported node type: {type(node).__name__}")
+
+
+# Use shared pattern matching utilities
+MATH_OPERATORS = PatternMatchingHelper.MATH_OPERATORS
+EXCLUDED_FUNCTION_NAMES = PatternMatchingHelper.EXCLUDED_FUNCTION_NAMES
+VARIABLE_PATTERN_DETAILED = PatternMatchingHelper.VARIABLE_PATTERN_DETAILED
+VARIABLE_PATTERN = PatternMatchingHelper.VARIABLE_PATTERN
 
 # Tuple of types for isinstance() checks
-VALID_EXPRESSION_TYPES = (VariableReference, FieldQnty, int, float, BinaryOperation, ConditionalExpression, Constant, UnaryFunction)
+VALID_EXPRESSION_TYPES = (VariableReference, Quantity, int, float, BinaryOperation, ConditionalExpression, Constant, UnaryFunction)
 
 
 # ========== CUSTOM EXCEPTIONS ==========
 
 
-class SolverError(RuntimeError):
-    """Raised when the solving process fails."""
-
-    pass
-
-
 class EquationReconstructionError(Exception):
     """Base exception for equation reconstruction errors."""
 
     pass
 
 
-class MalformedExpressionError(EquationReconstructionError):
-    """Raised when expressions are malformed and cannot be reconstructed."""
-
-    pass
+# ========== SHARED UTILITIES ==========
 
 
-class NamespaceMappingError(EquationReconstructionError):
-    """Raised when namespace mapping fails."""
+class DependencyAwareSolver:
+    """Solver that handles equations with dependency ordering."""
 
-    pass
+    def __init__(self, variables: VariableDict):
+        """Initialize the dependency-aware solver.
+
+        Args:
+            variables: Dictionary of variables available for solving
+        """
+        self.variables = variables
+
+    def can_evaluate_expression(self, expression_str: str) -> bool:
+        """Check if an expression can be evaluated with current known variables.
+
+        Args:
+            expression_str: The expression string to check
+
+        Returns:
+            True if all variables in the expression have known values
+        """
+        try:
+            # Extract variables from the expression
+            var_names = PatternMatchingHelper.extract_variables_from_expression_string(expression_str)
+
+            # Check if all variables have known values
+            for var_name in var_names:
+                if var_name in self.variables:
+                    var = self.variables[var_name]
+                    if hasattr(var, "value") and var.value is None:
+                        return False
+                else:
+                    return False  # Variable not found
+
+            return True
+        except Exception:
+            return False
+
+    def solve_equations_with_dependencies(self, equation_specs: list[tuple[str, str]]) -> bool:
+        """Solve equations in dependency order.
+
+        Args:
+            equation_specs: List of (target_var, expression) tuples
+
+        Returns:
+            True if all equations were solved successfully
+        """
+        from qnty.algebra import solve
+
+        # Track which equations have been solved
+        remaining_equations = list(equation_specs)
+        max_iterations = len(equation_specs) * 2  # Prevent infinite loops
+        iterations = 0
+
+        while remaining_equations and iterations < max_iterations:
+            iterations += 1
+            progress_made = False
+
+            # Try to solve equations that can be evaluated now
+            for i, (target_var, expression) in enumerate(remaining_equations):
+                if self.can_evaluate_expression(expression):
+                    try:
+                        # Evaluate the expression
+                        evaluator = SafeExpressionEvaluator(self.variables)
+                        rhs = evaluator.safe_eval(expression)
+
+                        # Solve for the target variable
+                        success = solve(self.variables[target_var], rhs)
+                        if success:
+                            # Remove this equation from remaining list
+                            remaining_equations.pop(i)
+                            progress_made = True
+                            break
+
+                    except Exception:
+                        # Skip this equation for now
+                        continue
+
+            # If no progress was made, we might have unsolvable dependencies
+            if not progress_made:
+                break
+
+        return len(remaining_equations) == 0
 
 
-class PatternReconstructionError(EquationReconstructionError):
-    """Raised when mathematical pattern reconstruction fails."""
+class ExpressionEvaluationMixin:
+    """Mixin providing shared expression evaluation utilities."""
 
-    pass
+    @staticmethod
+    def create_safe_evaluator(variables: VariableDict) -> SafeExpressionEvaluator:
+        """Create a standardized safe expression evaluator.
+
+        Args:
+            variables: Dictionary of available variables
+
+        Returns:
+            Configured SafeExpressionEvaluator instance
+        """
+        eval_context = dict(variables)
+        return SafeExpressionEvaluator(eval_context, SafeExpressionEvaluator.DEFAULT_ALLOWED_FUNCTIONS.copy())
+
+    @staticmethod
+    def extract_variables_from_expression(expression_str: str, exclude_functions: bool = True) -> list[str]:
+        """Extract variable names from an expression string.
+
+        Args:
+            expression_str: The expression string to parse
+            exclude_functions: Whether to exclude known function names
+
+        Returns:
+            List of variable names found in the expression
+        """
+        return PatternMatchingHelper.extract_variables_from_expression_string(expression_str, exclude_functions)
 
 
-# ========== EXPRESSION PARSER ==========
-
-
-class ExpressionParser:
-    """
-    Focused class for parsing and rebuilding mathematical expressions.
-
-    Handles conversion from string patterns to Expression objects using
-    safe evaluation techniques and proper namespace management.
-    """
+class BaseExpressionHandler(ExpressionEvaluationMixin, SafeExecutionMixin):
+    """Base class for expression handling components."""
 
     def __init__(self, variables: VariableDict, logger: Logger):
-        """
-        Initialize the expression parser.
+        """Initialize the base expression handler.
 
         Args:
             variables: Dictionary of available variables
@@ -96,6 +342,18 @@ class ExpressionParser:
         self.variables = variables
         self.logger = logger
 
+
+# ========== EXPRESSION PARSER ==========
+
+
+class ExpressionParser(BaseExpressionHandler):
+    """
+    Focused class for parsing and rebuilding mathematical expressions.
+
+    Handles conversion from string patterns to Expression objects using
+    safe evaluation techniques and proper namespace management.
+    """
+
     def parse_composite_expression_pattern(self, composite_symbol: str) -> Any | None:
         """
         Parse a composite expression pattern and reconstruct it using available variables.
@@ -113,42 +371,40 @@ class ExpressionParser:
         if not composite_symbol or not isinstance(composite_symbol, str):
             return None
 
-        try:
-            # Extract variable names from the composite expression
-            var_matches = VARIABLE_PATTERN_DETAILED.findall(composite_symbol)
-            if not var_matches:
-                return None
+        return self.safe_execute(f"parse composite expression '{composite_symbol}'", lambda: self._parse_composite_expression_impl(composite_symbol))
 
-            # Find the namespace that contains most of these variables
-            best_namespace = self._find_best_namespace_for_variables(var_matches)
-            if not best_namespace:
-                return None
-
-            # Create substitution mapping
-            substitution_map = {}
-            for var_name in var_matches:
-                if var_name not in EXCLUDED_FUNCTION_NAMES:
-                    namespaced_name = f"{best_namespace}_{var_name}"
-                    if namespaced_name in self.variables:
-                        substitution_map[var_name] = namespaced_name
-
-            if not substitution_map:
-                return None
-
-            # Substitute variables in the expression string
-            substituted_expr = composite_symbol
-            for original, namespaced in substitution_map.items():
-                # Use word boundary regex for precise replacement
-                pattern = r"\b" + re.escape(original) + r"\b"
-                substituted_expr = re.sub(pattern, namespaced, substituted_expr)
-
-            # Try to build the expression from the substituted string
-            return self._build_expression_from_string(substituted_expr)
-
-        except Exception as e:
-            self.logger.debug(f"Failed to parse composite expression '{composite_symbol}': {e}")
+    def _parse_composite_expression_impl(self, composite_symbol: str) -> Any | None:
+        """Implementation of composite expression parsing."""
+        # Extract variable names from the composite expression
+        var_matches = self.extract_variables_from_expression(composite_symbol)
+        if not var_matches:
             return None
 
+        # Find the namespace that contains most of these variables
+        best_namespace = self._find_best_namespace_for_variables(var_matches)
+        if not best_namespace:
+            return None
+
+        # Create substitution mapping
+        substitution_map = {}
+        for var_name in var_matches:
+            namespaced_name = f"{best_namespace}_{var_name}"
+            if namespaced_name in self.variables:
+                substitution_map[var_name] = namespaced_name
+
+        if not substitution_map:
+            return None
+
+        # Substitute variables in the expression string
+        substituted_expr = composite_symbol
+        for original, namespaced in substitution_map.items():
+            # Use word boundary regex for precise replacement
+            pattern = r"\b" + re.escape(original) + r"\b"
+            substituted_expr = re.sub(pattern, namespaced, substituted_expr)
+
+        # Try to build the expression from the substituted string
+        return self._build_expression_from_string(substituted_expr)
+
     def _find_best_namespace_for_variables(self, var_names: list[str]) -> str | None:
         """Find the namespace that contains the most variables from the list."""
         namespace_scores = {}
@@ -178,33 +434,7 @@ class ExpressionParser:
         Returns:
             Built expression object if successful, None otherwise
         """
-        try:
-            # Create a safe evaluation context with only our variables
-            eval_context = {}
-
-            # Add variables to context
-            for var_symbol, var_obj in self.variables.items():
-                eval_context[var_symbol] = var_obj
-
-            # Add safe mathematical functions
-            eval_context.update(
-                {
-                    "sin": sin,
-                    "cos": cos,
-                    "abs": abs,
-                    "min": min,
-                    "max": max,
-                    "__builtins__": {},  # Disable built-ins for security
-                }
-            )
-
-            # Safely evaluate the expression
-            result = eval(expr_string, eval_context, {})
-            return result
-
-        except Exception as e:
-            self.logger.debug(f"Failed to build expression from string '{expr_string}': {e}")
-            return None
+        return self.safe_execute(f"build expression from string '{expr_string}'", lambda: self.create_safe_evaluator(self.variables).safe_eval(expr_string))
 
     def parse_malformed_variable_pattern(self, malformed_symbol: str) -> Any | None:
         """
@@ -291,7 +521,7 @@ class ExpressionParser:
             self.logger.debug(f"Failed to parse and rebuild expression: {e}")
             return None
 
-    def _substitute_in_expression(self, _expr: Any, substitutions: dict[str, Any]) -> Any | None:
+    def _substitute_in_expression(self, _: Any, substitutions: dict[str, Any]) -> Any | None:
         """
         Substitute reconstructed components back into an expression tree.
 
@@ -313,7 +543,7 @@ class ExpressionParser:
 # ========== NAMESPACE MAPPER ==========
 
 
-class NamespaceMapper:
+class NamespaceMapper(BaseExpressionHandler):
     """
     Focused class for handling variable namespace mapping operations.
 
@@ -329,8 +559,7 @@ class NamespaceMapper:
             variables: Dictionary of available variables
             logger: Logger for debugging
         """
-        self.variables = variables
-        self.logger = logger
+        super().__init__(variables, logger)
 
         # Performance optimization caches
         self._namespace_cache: dict[str, set[str]] = {}
@@ -353,13 +582,9 @@ class NamespaceMapper:
             if not isinstance(missing_var, str):
                 continue
 
-            # Extract variable names using regex
-            matches = VARIABLE_PATTERN.findall(missing_var)
-
-            for match in matches:
-                # Skip function names
-                if match not in EXCLUDED_FUNCTION_NAMES:
-                    base_vars.add(match)
+            # Extract variable names using the shared utility
+            matches = self.extract_variables_from_expression(missing_var)
+            base_vars.update(matches)
 
         return base_vars
 
@@ -422,34 +647,6 @@ class NamespaceMapper:
         # Return shortest match (least nested namespace)
         return min(candidates, key=len) if candidates else None
 
-    def get_namespaces_for_variable(self, base_var: str) -> set[str]:
-        """
-        Get all namespaces that contain a particular base variable.
-
-        Args:
-            base_var: Base variable name
-
-        Returns:
-            Set of namespace prefixes that contain the variable
-        """
-        # Use cache for performance
-        if base_var in self._namespace_cache:
-            return self._namespace_cache[base_var]
-
-        namespaces = set()
-
-        for var_name in self.variables.keys():
-            if var_name.endswith(f"_{base_var}") and "_" in var_name:
-                # Extract namespace (everything before the last underscore + base_var)
-                parts = var_name.split("_")
-                if len(parts) >= 2 and parts[-1] == base_var:
-                    namespace = "_".join(parts[:-1])
-                    namespaces.add(namespace)
-
-        # Cache the result
-        self._namespace_cache[base_var] = namespaces
-        return namespaces
-
     def clear_caches(self) -> None:
         """Clear all internal caches."""
         self._namespace_cache.clear()
@@ -460,7 +657,7 @@ class NamespaceMapper:
 # ========== COMPOSITE EXPRESSION REBUILDER ==========
 
 
-class CompositeExpressionRebuilder:
+class CompositeExpressionRebuilder(BaseExpressionHandler):
     """
     Focused class for rebuilding composite expressions from malformed patterns.
 
@@ -468,17 +665,6 @@ class CompositeExpressionRebuilder:
     evaluation and provides methods to recover the original mathematical structure.
     """
 
-    def __init__(self, variables: VariableDict, logger: Logger):
-        """
-        Initialize the composite expression rebuilder.
-
-        Args:
-            variables: Dictionary of available variables
-            logger: Logger for debugging
-        """
-        self.variables = variables
-        self.logger = logger
-
     def identify_malformed_variables(self, missing_vars: list[str]) -> list[str]:
         """
         Identify which missing variables are malformed from proxy evaluation.
@@ -528,7 +714,7 @@ class CompositeExpressionRebuilder:
 
         return False
 
-    def reconstruct_malformed_proxy_expression(self, equation: Equation, _malformed_vars: list[str]) -> Any | None:
+    def reconstruct_malformed_proxy_expression(self, equation: Equation, _: list[str]) -> Any | None:
         """
         Generically reconstruct expressions that were malformed due to proxy evaluation.
 
@@ -643,21 +829,13 @@ class CompositeExpressionRebuilder:
 
     def _safe_evaluate_pattern(self, pattern: str) -> Any | None:
         """Safely evaluate a reconstructed pattern."""
-        try:
-            # Create evaluation context with our variables  
-            eval_context: dict[str, Any] = dict(self.variables)
-            eval_context["__builtins__"] = {}  # Security
-
-            return eval(pattern, eval_context, {})
-
-        except Exception:
-            return None
+        return self.safe_execute(f"evaluate pattern '{pattern}'", lambda: self.create_safe_evaluator(self.variables).safe_eval(pattern))
 
     def _attempt_fallback_reconstruction(self, equation: Equation) -> Any | None:
         """Attempt fallback reconstruction methods."""
         try:
             # Try to get variables from the LHS and create a simple reconstruction
-            if isinstance(equation.lhs, FieldQnty | VariableReference):
+            if isinstance(equation.lhs, Quantity | VariableReference):
                 symbol = getattr(equation.lhs, "symbol", None)
                 if isinstance(symbol, str) and symbol in self.variables:
                     lhs_var = self.variables[symbol]
@@ -678,7 +856,7 @@ class CompositeExpressionRebuilder:
             return var_symbol.split("_")[0]
         return None
 
-    def _create_simple_reconstruction(self, namespace: str, target_var: FieldQnty) -> Any | None:
+    def _create_simple_reconstruction(self, namespace: str, target_var: Quantity) -> Any | None:
         """Create a simple reconstruction based on namespace variables."""
         try:
             # Find other variables in the same namespace
@@ -698,7 +876,7 @@ class CompositeExpressionRebuilder:
 # ========== DELAYED EXPRESSION RESOLVER ==========
 
 
-class DelayedExpressionResolver:
+class DelayedExpressionResolver(BaseExpressionHandler):
     """
     Focused class for resolving delayed expressions and equations.
 
@@ -706,17 +884,6 @@ class DelayedExpressionResolver:
     safe resolution with proper type checking and context management.
     """
 
-    def __init__(self, variables: VariableDict, logger: Logger):
-        """
-        Initialize the delayed expression resolver.
-
-        Args:
-            variables: Dictionary of available variables
-            logger: Logger for debugging
-        """
-        self.variables = variables
-        self.logger = logger
-
     def contains_delayed_expressions(self, equation: Equation) -> bool:
         """
         Check if an equation contains delayed expressions that need resolution.
@@ -757,8 +924,8 @@ class DelayedExpressionResolver:
                 return None
 
             # Create new equation with resolved RHS
-            if isinstance(equation.lhs, FieldQnty):
-                return equation.lhs.equals(resolved_rhs)
+            if isinstance(equation.lhs, Quantity):
+                return create_equation(equation.lhs, resolved_rhs)
 
             return None
 
@@ -782,7 +949,7 @@ class DelayedExpressionResolver:
                 # Check if this expression has a resolve method
                 if hasattr(expr, "resolve") and callable(getattr(expr, "resolve", None)):
                     context = self.variables.copy()
-                    return getattr(expr, "resolve")(context)
+                    return expr.resolve(context)  # type: ignore[attr-defined]
                 return expr
 
             # Try to recursively resolve components for binary operations
@@ -821,7 +988,7 @@ class EquationReconstructor:
 
     Example Usage:
         reconstructor = EquationReconstructor(problem)
-        fixed_equation = reconstructor.fix_malformed_equation(broken_equation)
+        fixed_equation = reconstructor._reconstruct_composite_expressions(broken_equation, missing_vars)
     """
 
     def __init__(self, problem: Any) -> None:
@@ -854,49 +1021,6 @@ class EquationReconstructor:
         self.delayed_resolver = DelayedExpressionResolver(self.variables, self.logger)
         self.composite_rebuilder = CompositeExpressionRebuilder(self.variables, self.logger)
 
-    def fix_malformed_equation(self, equation: Equation) -> ReconstructionResult:
-        """
-        Generic method to fix equations that were malformed during class definition.
-
-        Specifically handles composite expressions like '(D - (T - c) * 2.0)' that should
-        reference namespaced variables like 'branch_D', 'branch_T', 'branch_c'.
-
-        Args:
-            equation: The malformed equation to fix
-
-        Returns:
-            Fixed equation if reconstruction succeeds, None otherwise
-
-        Raises:
-            EquationReconstructionError: If equation reconstruction fails with detailed error
-        """
-        if equation is None:
-            return None
-
-        try:
-            # Get all variables referenced in the equation
-            all_vars = equation.get_all_variables()
-            missing_vars = [var for var in all_vars if var not in self.variables]
-
-            if not missing_vars:
-                return equation  # Nothing to fix
-
-            self.logger.debug(f"Found missing variables in equation: {missing_vars}")
-
-            # Attempt to reconstruct equations with composite variables using generic approach
-            fixed_equation = self._reconstruct_composite_expressions(equation, missing_vars)
-
-            if fixed_equation:
-                self.logger.debug(f"Successfully reconstructed equation: {fixed_equation}")
-                return fixed_equation
-            else:
-                self.logger.debug("Failed to reconstruct equation")
-                return None
-
-        except Exception as e:
-            self.logger.debug(f"Error in fix_malformed_equation: {e}")
-            return None
-
     def _reconstruct_composite_expressions(self, equation: Equation, missing_vars: list[str]) -> ReconstructionResult:
         """
         Generic reconstruction of equations with composite expressions.
@@ -912,7 +1036,7 @@ class EquationReconstructor:
             Reconstructed equation if successful, None otherwise
 
         Raises:
-            NamespaceMappingError: If namespace mapping fails
+            EquationReconstructionError: If namespace mapping fails
         """
         if not missing_vars:
             return None
@@ -967,7 +1091,7 @@ class EquationReconstructor:
                         # Replace the original equation's RHS or LHS
                         lhs_var = self._get_lhs_variable(equation)
                         if lhs_var:
-                            return lhs_var.equals(reconstructed_expr)
+                            return create_equation(lhs_var, reconstructed_expr)
 
             return None
 
@@ -1007,7 +1131,7 @@ class EquationReconstructor:
             self.logger.debug(f"Error in expression reconstruction: {e}")
             return None
 
-    def _get_lhs_variable(self, equation: Equation) -> FieldQnty | None:
+    def _get_lhs_variable(self, equation: Equation) -> Quantity | None:
         """
         Safely extract the left-hand side variable from an equation.
 
@@ -1024,7 +1148,7 @@ class EquationReconstructor:
                 if var_name in self.variables:
                     return self.variables[var_name]
             # Check if lhs is a FieldQnty with symbol attribute
-            elif isinstance(equation.lhs, FieldQnty):
+            elif isinstance(equation.lhs, Quantity):
                 symbol = getattr(equation.lhs, "symbol", None)
                 if isinstance(symbol, str) and symbol in self.variables:
                     return self.variables[symbol]
@@ -1057,111 +1181,6 @@ class EquationReconstructor:
         """
         return self.delayed_resolver.resolve_delayed_equation(equation)
 
-    def should_attempt_reconstruction(self, equation: Equation) -> bool:
-        """
-        Determine if we should attempt to reconstruct this equation.
-
-        Only attempt reconstruction for simple mathematical expressions,
-        not complex structures like conditionals.
-
-        Args:
-            equation: The equation to evaluate for reconstruction
-
-        Returns:
-            True if reconstruction should be attempted
-        """
-        if equation is None:
-            return False
-
-        try:
-            equation_str = str(equation)
-
-            # Skip conditional equations using constant set
-            if any(pattern in equation_str for pattern in CONDITIONAL_PATTERNS):
-                return False
-
-            # Skip equations with complex function calls
-            if any(func in equation_str for func in FUNCTION_PATTERNS):
-                # These might be complex - only attempt if they're in the problematic patterns
-                self.logger.debug(f"Equation contains complex functions: {equation_str}")
-
-            # Only attempt if the missing variables look like mathematical expressions
-            all_vars = equation.get_all_variables()
-            missing_vars = [var for var in all_vars if var not in self.variables]
-
-            for missing_var in missing_vars:
-                # Check if this looks like a mathematical expression we can handle
-                if any(char in missing_var for char in MATH_OPERATORS):
-                    return True
-
-            return False
-
-        except Exception as e:
-            self.logger.debug(f"Error in should_attempt_reconstruction: {e}")
-            return False
-
-    def reconstruct_composite_expressions_generically(self, equation: Equation) -> ReconstructionResult:
-        """
-        Generically reconstruct equations with composite expressions by parsing the
-        composite symbols and rebuilding them from existing variables.
-
-        Enhanced to handle malformed expressions from proxy evaluation.
-
-        Args:
-            equation: The equation to reconstruct
-
-        Returns:
-            Reconstructed equation if successful, None otherwise
-
-        Raises:
-            MalformedExpressionError: If expressions are too malformed to reconstruct
-        """
-        if equation is None:
-            return None
-
-        try:
-            all_vars = equation.get_all_variables()
-            missing_vars = [var for var in all_vars if var not in self.variables]
-
-            if not missing_vars:
-                return equation
-
-            # Get the LHS variable with proper validation
-            lhs_var = self._get_lhs_variable(equation)
-            if lhs_var is None:
-                return None
-
-            # Check for malformed expressions that contain evaluated numeric values
-            malformed_vars = self.composite_rebuilder.identify_malformed_variables(missing_vars)
-
-            if malformed_vars:
-                # This is a malformed expression from proxy evaluation
-                reconstructed_rhs = self.composite_rebuilder.reconstruct_malformed_proxy_expression(equation, malformed_vars)
-                if reconstructed_rhs:
-                    return lhs_var.equals(reconstructed_rhs)
-                return None
-
-            # Reconstruct the RHS by parsing and rebuilding composite expressions
-            reconstructed_rhs = self.expression_parser.parse_and_rebuild_expression(equation.rhs, missing_vars)
-
-            if reconstructed_rhs:
-                return lhs_var.equals(reconstructed_rhs)
-
-            return None
-
-        except Exception as e:
-            self.logger.debug(f"Reconstruction failed: {e}")
-            return None
-
-    def _clear_caches(self) -> None:
-        """
-        Clear all internal caches. Should be called when variables change.
-
-        This method provides a way to reset cached data when the problem
-        state changes, ensuring cache consistency.
-        """
-        self.namespace_mapper.clear_caches()
-
     # Delegation methods for public API compatibility
     def parse_composite_expression_pattern(self, composite_symbol: str) -> Any | None:
         """
@@ -1208,9 +1227,6 @@ __all__ = [
     "NamespaceMapper",
     "CompositeExpressionRebuilder",
     "DelayedExpressionResolver",
-    "SolverError",
+    "SafeExpressionEvaluator",
     "EquationReconstructionError",
-    "MalformedExpressionError",
-    "NamespaceMappingError",
-    "PatternReconstructionError",
 ]
