@@ -12,9 +12,9 @@ except ImportError:
 
 from qnty.solving.order import Order
 
-from ...equations import Equation
-from ...quantities import Quantity
-from ...quantities.field_qnty import FieldQnty
+from ...algebra import Equation
+from ...core.quantity import FieldQuantity, Quantity
+from ..utils import SolverConstants
 from .base import BaseSolver, SolveResult
 
 
@@ -43,14 +43,7 @@ class SimultaneousEquationSolver(BaseSolver):
         3×3 system: Complex engineering systems with interdependent variables
     """
 
-    # Constants for numerical stability and validation
-    MIN_SYSTEM_SIZE = 2
-    MAX_CONDITION_NUMBER = 1e12
-    DEFAULT_TOLERANCE = 1e-10
-
-    # Performance optimization constants
-    LARGE_SYSTEM_THRESHOLD = 100  # Switch to optimized algorithms for n > 100
-    SPARSE_THRESHOLD = 0.1  # Use sparse matrices if density < 10%
+    # Use consolidated constants from utils module (SolverConstants)
 
     def can_handle(self, equations: list[Equation], unknowns: set[str], dependency_graph: Order | None = None, analysis: dict[str, Any] | None = None) -> bool:
         """
@@ -75,7 +68,7 @@ class SimultaneousEquationSolver(BaseSolver):
         num_unknowns = len(unknowns)
 
         # Validate square system with minimum size
-        if system_size != num_unknowns or system_size < self.MIN_SYSTEM_SIZE:
+        if system_size != num_unknowns or system_size < SolverConstants.MIN_SYSTEM_SIZE:
             return False
 
         # Only handle systems with cycles (mutual dependencies)
@@ -84,7 +77,9 @@ class SimultaneousEquationSolver(BaseSolver):
         has_cycles = analysis.get("has_cycles", False)
         return bool(has_cycles)
 
-    def solve(self, equations: list[Equation], variables: dict[str, FieldQnty], dependency_graph: Order | None = None, max_iterations: int = 100, tolerance: float = DEFAULT_TOLERANCE) -> SolveResult:
+    def solve(
+        self, equations: list[Equation], variables: dict[str, FieldQuantity], dependency_graph: Order | None = None, max_iterations: int = 100, tolerance: float = SolverConstants.DEFAULT_TOLERANCE
+    ) -> SolveResult:
         """
         Solve the n×n simultaneous system using matrix operations.
 
@@ -117,7 +112,7 @@ class SimultaneousEquationSolver(BaseSolver):
         try:
             solution_vector = self._solve_matrix_system(equations, unknown_variable_names, working_variables)
             if solution_vector is None:
-                return SolveResult(variables=working_variables, steps=self.steps, success=False, message="Failed to solve matrix system", method="SimultaneousEquationSolver")
+                return self._create_error_result(working_variables, "Failed to solve matrix system")
 
             # Step 3: Update variables with solutions
             self._apply_solution_to_variables(unknown_variable_names, solution_vector, working_variables)
@@ -130,9 +125,9 @@ class SimultaneousEquationSolver(BaseSolver):
             )
 
         except Exception as general_error:
-            return SolveResult(variables=working_variables, steps=self.steps, success=False, message=f"Simultaneous solving failed: {general_error}", method="SimultaneousEquationSolver")
+            return self._create_error_result(working_variables, f"Simultaneous solving failed: {general_error}")
 
-    def _validate_system(self, equations: list[Equation], variables: dict[str, FieldQnty]) -> SolveResult:
+    def _validate_system(self, equations: list[Equation], variables: dict[str, FieldQuantity]) -> SolveResult:
         """
         Validate that the system meets requirements for simultaneous solving.
 
@@ -144,7 +139,7 @@ class SimultaneousEquationSolver(BaseSolver):
         num_equations = len(equations)
 
         # Validate square system with minimum size
-        if num_unknowns != num_equations or num_unknowns < self.MIN_SYSTEM_SIZE:
+        if num_unknowns != num_equations or num_unknowns < SolverConstants.MIN_SYSTEM_SIZE:
             return SolveResult(
                 variables=variables,
                 steps=self.steps,
@@ -158,7 +153,7 @@ class SimultaneousEquationSolver(BaseSolver):
 
         return SolveResult(variables=variables, steps=self.steps, success=True, message="System validation passed", method="SimultaneousEquationSolver")
 
-    def _solve_matrix_system(self, equations: list[Equation], unknown_variables: list[str], working_variables: dict[str, FieldQnty]) -> np.ndarray | None:
+    def _solve_matrix_system(self, equations: list[Equation], unknown_variables: list[str], working_variables: dict[str, FieldQuantity]) -> np.ndarray | None:
         """
         Extract coefficient matrix and solve the linear system.
 
@@ -175,7 +170,7 @@ class SimultaneousEquationSolver(BaseSolver):
 
         # Check numerical stability via condition number
         condition_number = np.linalg.cond(coefficient_matrix)
-        if condition_number > self.MAX_CONDITION_NUMBER:
+        if condition_number > SolverConstants.MAX_CONDITION_NUMBER:
             if self.logger:
                 # Use debug level for expected fallback scenarios (systems with conditionals)
                 if np.isinf(condition_number):
@@ -207,7 +202,7 @@ class SimultaneousEquationSolver(BaseSolver):
         Returns:
             Solution vector for the system Ax = b
         """
-        if system_size <= self.LARGE_SYSTEM_THRESHOLD:
+        if system_size <= SolverConstants.LARGE_SYSTEM_THRESHOLD:
             # Use standard NumPy solver for small-medium systems
             return np.linalg.solve(coefficient_matrix, constant_vector)
         else:
@@ -218,15 +213,15 @@ class SimultaneousEquationSolver(BaseSolver):
             # Check matrix density to decide between dense/sparse algorithms
             density = np.count_nonzero(coefficient_matrix) / coefficient_matrix.size
 
-            if density < self.SPARSE_THRESHOLD:
+            if density < SolverConstants.SPARSE_THRESHOLD:
                 # Use sparse matrix algorithms
                 if self.logger:
-                    self.logger.debug(f"Matrix density {density:.3f} < {self.SPARSE_THRESHOLD}, using sparse algorithms")
+                    self.logger.debug(f"Matrix density {density:.3f} < {SolverConstants.SPARSE_THRESHOLD}, using sparse algorithms")
                 return self._solve_sparse_system(coefficient_matrix, constant_vector)
             else:
                 # Use optimized dense algorithms
                 if self.logger:
-                    self.logger.debug(f"Matrix density {density:.3f} >= {self.SPARSE_THRESHOLD}, using optimized dense algorithms")
+                    self.logger.debug(f"Matrix density {density:.3f} >= {SolverConstants.SPARSE_THRESHOLD}, using optimized dense algorithms")
                 return self._solve_large_dense_system(coefficient_matrix, constant_vector)
 
     def _solve_sparse_system(self, coefficient_matrix: np.ndarray, constant_vector: np.ndarray) -> np.ndarray:
@@ -243,7 +238,7 @@ class SimultaneousEquationSolver(BaseSolver):
             return scipy_solve(coefficient_matrix, constant_vector, assume_a="gen")
         return np.linalg.solve(coefficient_matrix, constant_vector)
 
-    def _apply_solution_to_variables(self, unknown_variables: list[str], solution_vector: np.ndarray, working_variables: dict[str, FieldQnty]):
+    def _apply_solution_to_variables(self, unknown_variables: list[str], solution_vector: np.ndarray, working_variables: dict[str, FieldQuantity]):
         """
         Apply solution values to variables and record solving steps.
         """
@@ -251,7 +246,7 @@ class SimultaneousEquationSolver(BaseSolver):
             solution_value = float(solution_vector[i])
             self._update_variable_with_solution(variable_name, solution_value, working_variables)
 
-    def _verify_solution_quality(self, equations: list[Equation], working_variables: dict[str, FieldQnty], tolerance: float) -> SolveResult:
+    def _verify_solution_quality(self, equations: list[Equation], working_variables: dict[str, FieldQuantity], tolerance: float) -> SolveResult:
         """
         Verify solution quality by checking equation residuals.
 
@@ -279,7 +274,7 @@ class SimultaneousEquationSolver(BaseSolver):
 
         return SolveResult(variables=working_variables, steps=[], success=is_successful, message=success_message, method="SimultaneousEquationSolver")
 
-    def _extract_matrix_system(self, equations: list[Equation], unknown_variables: list[str], variables: dict[str, FieldQnty]) -> tuple[np.ndarray | None, np.ndarray | None]:
+    def _extract_matrix_system(self, equations: list[Equation], unknown_variables: list[str], variables: dict[str, FieldQuantity]) -> tuple[np.ndarray | None, np.ndarray | None]:
         """
         Extract coefficient matrix A and constant vector b from the system of equations.
 
@@ -323,7 +318,7 @@ class SimultaneousEquationSolver(BaseSolver):
         except Exception:
             return None, None
 
-    def _extract_linear_coefficients_vector(self, equation: Equation, unknown_variables: list[str], variables: dict[str, FieldQnty]) -> list[float] | None:
+    def _extract_linear_coefficients_vector(self, equation: Equation, unknown_variables: list[str], variables: dict[str, FieldQuantity]) -> list[float] | None:
         """
         Extract linear coefficients from equation using numerical differentiation.
 
@@ -377,7 +372,7 @@ class SimultaneousEquationSolver(BaseSolver):
         except Exception:
             return None
 
-    def _calculate_equation_residual(self, equation: Equation, test_variables: dict[str, FieldQnty]) -> float:
+    def _calculate_equation_residual(self, equation: Equation, test_variables: dict[str, FieldQuantity]) -> float:
         """
         Calculate equation residual (LHS - RHS) with proper unit handling.
 
@@ -401,7 +396,7 @@ class SimultaneousEquationSolver(BaseSolver):
             # Fallback for cases where evaluation fails
             return float("inf")
 
-    def _update_variable_with_solution(self, variable_symbol: str, solution_value: float, variables: dict[str, FieldQnty]):
+    def _update_variable_with_solution(self, variable_symbol: str, solution_value: float, variables: dict[str, FieldQuantity]):
         """
         Update a variable with its solved value and record the solving step.
 
@@ -413,14 +408,14 @@ class SimultaneousEquationSolver(BaseSolver):
         original_variable = variables[variable_symbol]
         if original_variable.quantity is None:
             raise ValueError(f"Variable {variable_symbol} has no quantity")
-        result_unit = original_variable.quantity.unit
-        solution_quantity = Quantity(solution_value, result_unit)
+        # Use consolidated utility for unit resolution
+        result_unit = self._resolve_preferred_unit(original_variable, variable_symbol)
 
-        # Preserve the original variable name and create solved variable
-        original_name = original_variable.name
-        solved_variable = FieldQnty(name=original_name, expected_dimension=solution_quantity.dimension, is_known=True)
-        solved_variable.quantity = solution_quantity
-        solved_variable.symbol = variable_symbol
+        solution_quantity = Quantity.from_value(solution_value, result_unit, name="solution")
+
+        # Create solved variable with correct constructor
+        solved_variable = FieldQuantity(name=original_variable.name, dim=original_variable.dim, value=solution_value, preferred=result_unit)
+        solved_variable._symbol = variable_symbol
         variables[variable_symbol] = solved_variable
 
         # Record solving step for tracking
@@ -432,7 +427,7 @@ class SimultaneousEquationSolver(BaseSolver):
             "simultaneous",
         )
 
-    def _set_test_variables(self, test_vars: dict[str, FieldQnty], unknown_variables: list[str], active_index: int):
+    def _set_test_variables(self, test_vars: dict[str, FieldQuantity], unknown_variables: list[str], active_index: int):
         """
         Set test variables for coefficient extraction.
 
@@ -446,30 +441,10 @@ class SimultaneousEquationSolver(BaseSolver):
             original_var = test_vars[var_name]
             if original_var.quantity is None:
                 raise ValueError(f"Variable {var_name} has no quantity")
-            test_var = FieldQnty(name=f"test_{var_name}", expected_dimension=original_var.quantity.dimension, is_known=True)
-            test_var.quantity = Quantity(test_value, original_var.quantity.unit)
-            test_var.symbol = var_name
+
+            # Use consolidated utility for unit resolution
+            preferred_unit = self._resolve_preferred_unit(original_var, var_name)
+
+            test_var = FieldQuantity(name=f"test_{var_name}", dim=original_var.dim, value=test_value, preferred=preferred_unit)
+            test_var._symbol = var_name
             test_vars[var_name] = test_var
-
-    def _extract_numerical_value(self, value: Any) -> float:
-        """
-        Extract numerical value from various quantity types.
-
-        Args:
-            value: Value that may be a Quantity, float, int, or other numeric type
-
-        Returns:
-            Float representation of the value
-        """
-        # Check for Quantity type first (most common case)
-        if isinstance(value, Quantity):
-            return float(value.value)
-        # Handle primitive numeric types
-        elif isinstance(value, int | float):
-            return float(value)
-        # Handle objects with .value attribute as last resort
-        elif hasattr(value, "value"):
-            return float(value.value)
-        else:
-            # Last resort: try direct conversion
-            return float(value)
